@@ -1,3 +1,6 @@
+// Copyright 2021 System76 <info@system76.com>
+// SPDX-License-Identifier: MPL-2.0
+
 use async_io::Timer;
 use async_stream::stream;
 use futures::stream::{Stream, StreamExt};
@@ -49,7 +52,7 @@ pub fn apt_lock_found(paths: &[&Path]) -> bool {
         if let Ok(fdinfos) = proc.fd() {
             for fdinfo in fdinfos {
                 if let FDTarget::Path(path) = fdinfo.target {
-                    if paths.into_iter().any(|&p| &*path == p) {
+                    if paths.iter().any(|&p| &*path == p) {
                         return true;
                     }
                 }
